
/*

Works just like CNet's HELP cmd, but with the following exception:

Users do NOT have to exactly match the names of your help-files.
Users can enter HELP and type:
 1> FEEDBACK
 2> FEEDBAC
 3> FEEDBA
 4> FEEDB
 5> FEED
 6> FEE
 7> FE
 8> F
 9> FEED BACK
10> FEED-BACK
11> Even "FeedMeTodayOK" or "FEEDxxxxx" works
and still get the help they need.
(CNet's HELP cmd would require that they enter just #1, exactly.)

Help.rexx gives them a list of possible guesses...
>
> Enter another topic (or "MENU") [none]: f
>
> There is no help available on "f".
>
> See help-file for "FaxGate"   [No]? No
> See help-file for "FAX"       [No]? No
> See help-file for "Feedback"  [No]? No
> See help-file for "Find"      [No]? No
> See help-file for "Finger"    [No]? No
>
> Enter another topic (or "MENU") [none]:

o) Allows "MENU" or "?" or "/" to return you to the main menu.

o) Keeps log of usage:
      Which of your cmds are users most often needing help on?
      Which help-files are they successfully finding?
      Which are they attempting to locate, but can't?  (Better create those!)

o) The users can enter upper and lowercase text and have it
   ignored.  Currently CNet forces only uppercase input and the user sits
   there trying to flip his caps key ON/OFF, when it isn't even on in the
   1st place.  (ugh)

o) Makes the "WHO" "where-string" string say "Help-SubSystem"
   (I'm sure some users might want to help-out others that
   seem to constantly be living inside "HELP".)

Installation:
   1) Edit CNet:BBSMENU to remove CNet's built-in HELP cmd.
      Change ALL the lines marked "Help" into "2Help".
      (You'll still be able to run it online with the "2Help" cmd.)

   2) Onto the END of the cmd-list called "Available anywhere", add:
      > Help | {#0 Pfiles:Rexx/Help.rexx}

   3) Edit the variables below marked "SysOp-settable" items.
      The variable called "atmost" sets the sensitivity.
      You can have just the first 3-4 chars of user-input cause a match.
      Or the first 2, or 100 (for all).

   4) Copy Help.rexx TO pfiles:Help.rexx
      Copy HELP      TO SysText:Help/Help
      Copy Q         TO SysText:Help/Q       (optional)

Make sure you have "rexxsupport.library" in your "libs:" directory.

Also, by default Help.rexx writes the cmd that was executed to your
SysData:log/Port# files.  (You have to have CNet's "ArexxSays" log-
flag turned on.)

Bill Beogelein
Box 530441
Livonia, MI 48153
BBS 810-473-2020, FidoNet 1:2410/207

$VER: Help.rexx v1.1 Mon 03-Jan-94 04:43:42
   "MENU" or "?" or "/" all return you to the main menu.
   Also writes problems with "libs:rexxsupport.library" to logs.
   Better log-support for failed/successful attempts at getting help.
   Changes "WHO" "where-string" to "Help-SubSystem".
   Included "Q" help file.

$VER: Help.rexx v1.0 Mon 03-Jan-94 02:25:53
   Written/tested for CNet v3.01beta
   1st public release

Ignore:
   lz u CNet3:Help_Rexx.LHA pfiles:rexx/Help.rexx Help:Q
   lz u CNet3:Help_Rexx.LHA Help:Help Help:BB_CMDS a:zzzBBSad
   Copy CNet3:Help_Rexx.LHA UP:

Future plans and known bugs:
   Allow a 2nd dir for additional, optional, help-files.
   Please report ALL bugs.

*/

/************** Top of SysOp-settable variables **********************/

log    = 1        /* 1==writes to log                   0==no writes */
offset = 1302246  /* Is this where the cmd-line passed args start??? */
atmost = 3        /* The greatest # of chars needed for matches (3)  */

/*************** End of SysOp-settable variables *********************/

options results
path = "SysText:Help/"
'ChangeWhere' "HELP-SubSystem"

if( ~show('LIBRARY', "rexxsupport.library") ) then
   if( ~addlib("rexxsupport.library", 0, -30) ) then
   do
      'transmit' "n1*** Help.rexx can't open libs:rexxsupport.library"
      call ToLog("*** Can't open libs:rexxsupport.library")
      exit
   end

args=""
do i=offset to offset+(61*8) by 61     /* Join all the CNet passed args */
   'getUser' i
   j=RESULT
   args= strip(args j)
end

'transmit' "n1>i *** CNet-HELP by Bill Beogelein *** "

if( args = "") then 'sendFile' path || "MENU"
do forever
   if( args = "") then
   do
      'query' 'n1Enter another topic (or "?") [none]: '
      help = strip(RESULT)
   end
   else
      help = args
   args=""

   if( help=""  | help="###PANIC" ) then exit
   if( help="?" | help="/"        ) then help = "MENU"

   filename = path || help
   len      = length(help)
   if(len>atmost) then len=atmost      /* Match more cmds */

   if( exists(filename) ) then
   do
      'sendFile' filename
      call ToLog(help)
   end
   else
   do
      'transmit' 'n1There is no help available on "' || help || '".n1'
      call ToLog(left(help, 12) "(*** Fail)")

      filelist = showdir(path, 'FILES')   /* libs:rexxsupport.library call */

      do i=1 to 999
         try = word(filelist, i)

         if( try="" ) then leave       /* Done checking all possible guesses */
         if( match(help, try, len) ) then
         do
            buf = '"'try'"'
            'sendString' "See help-file for" left(buf, 12) "[No]? "
            'getChar'; ch = upper(RESULT)
            if( ch = 'Y' ) then
            do
               'transmit' "Yes"
               'sendFile' path || try
               call ToLog(try)
               leave
            end
            'transmit' "No"
         end
      end
   end
end
exit     /*** End of main ***/

ToLog:
   parse arg str
   if(log) then 'logEntry' "Help.rexx:" str
return

Match: PROCEDURE
   parse arg s1,s2,ln
   if( upper(left(s1, ln)) = upper(left(s2, ln)) ) then return 1
return 0

/*** EOF BBS: 810-473-2020, Fido: 1:2410/207 ***/
